#
# spec file for package createrepo_c
#
# Copyright (c) 2019 SUSE LLC
# Copyright (c) 2019 Neal Gompa <ngompa13@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?is_opensuse} || 0%{?suse_version} >= 1330
# Enable Python bindings on openSUSE
%bcond_without python3
%bcond_without tests
%else
%bcond_with python3
%bcond_with tests
%endif

%if (0%{?is_opensuse} && 0%{?sle_version} >= 150200) || 0%{?suse_version} >= 1550
# Enable enhanced DeltaRPM support
%bcond_without drpm
%else
%bcond_with drpm
%endif

%if (0%{?is_opensuse} && 0%{?sle_version} >= 150100) || 0%{?suse_version} >= 1550
%bcond_without zchunk
%bcond_without libmodulemd
%else
%bcond_with zchunk
%bcond_with libmodulemd
%endif

%if 0%{?sle_version} && 0%{?sle_version} < 160000
%bcond_with as_createrepo
%else
%bcond_without as_createrepo
%endif

%{!?make_build: %global make_build %{__make} %{?_smp_mflags}}

%define major 0
%define libname lib%{name}%{major}
%define devname lib%{name}-devel

Name:           createrepo_c
Version:        0.15.4
Release:        lp152.2.5
Summary:        RPM repository metadata generation utility
License:        GPL-2.0-or-later
Group:          System/Packages
URL:            https://github.com/rpm-software-management/createrepo_c
Source0:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz

%if %{with python3}
BuildRequires:  python3-devel
%endif
%if 0%{?is_opensuse} || 0%{?suse_version} >= 1330
BuildRequires:  python-rpm-macros
%endif
BuildRequires:  bash-completion
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  file-devel
BuildRequires:  glib2-devel >= 2.22.0
BuildRequires:  libbz2-devel
BuildRequires:  libcurl-devel
BuildRequires:  libexpat-devel
BuildRequires:  libxml2-devel
BuildRequires:  lzma-devel
BuildRequires:  openssl-devel
BuildRequires:  rpm-devel >= 4.9.0
BuildRequires:  sqlite3-devel
BuildRequires:  zlib-devel
%if %{with zchunk}
BuildRequires:  zchunk
BuildRequires:  zchunk-devel >= 0.9.11
%endif
%if %{with libmodulemd}
BuildRequires:  libmodulemd-devel >= 2.3.0
%endif
Requires:       %{libname}%{?_isa} = %{version}-%{release}
%if %{with tests}
BuildRequires:  python3
BuildRequires:  python3-nose
%endif
%if 0%{?suse_version} >= 1330
BuildRequires:  bash-completion-devel
%endif
%if %{with drpm}
BuildRequires:  drpm-devel >= 0.4.0
%endif

Requires:       %{libname} = %{version}-%{release}

%if %{with as_createrepo}
# Fully replaces createrepo
Requires(pre):  update-alternatives
Obsoletes:      createrepo < 0.11.0
Provides:       createrepo = %{version}-%{release}
%else
Requires(post): update-alternatives
Requires(postun): update-alternatives
%endif

Provides:       createrepo-implementation

# prevent provides from nonstandard paths:
%global __provides_exclude ^(%{python3_sitearch}/.*\\.so)$

%description
C implementation of Createrepo.
A set of utilities (createrepo_c, mergerepo_c, modifyrepo_c)
for generating a common metadata repository from a directory of
rpm packages and maintaining it.

%package -n %{libname}
Summary:        Library for repodata manipulation
Group:          System/Libraries

%description -n %{libname}
Libraries for applications using the createrepo_c library
for easy manipulation with a repodata.

%package -n %{devname}
Summary:        Library for repodata manipulation
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Requires:       pkgconfig
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
This package contains the createrepo_c C library and header files.
These development files are for easy manipulation with a repodata.

%package -n python3-%{name}
Summary:        Python 3 bindings for the createrepo_c library
Group:          Development/Libraries/Python
Requires:       %{libname}%{?_isa} = %{version}-%{release}
# Python 2 subpackage is fully dropped
Obsoletes:      python2-%{name} < 0.12.0

%description -n python3-%{name}
The Python 3 bindings for the createrepo_c library.

%prep
%autosetup -p1

# do not hardcode date in the docs
sed -i -e '/HTML_TIMESTAMP/d' doc/Doxyfile.in.in

%build
%define __builddir build
%cmake \
    %{!?with_zchunk:-DWITH_ZCHUNK=OFF} \
    %{!?with_libmodulemd:-DWITH_LIBMODULEMD=OFF} \
    %{!?with_drpm:-DENABLE_DRPM=OFF} \
    %{!?with_python3:-DENABLE_PYTHON=OFF} \
    -DPYTHON_DESIRED:str=3

%make_build
%make_build doc-c

%if %{with tests}
%check
%define __builddir build
%ctest
%endif

%install
%define __builddir build
%cmake_install

%if %{with as_createrepo}
for i in createrepo mergerepo modifyrepo sqliterepo;do
  ln -s %{_bindir}/$i\_c %{buildroot}%{_bindir}/$i
  echo ".so man8/$i\_c.8" > %{buildroot}%{_mandir}/man8/$i\.8
done
%else
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
for i in createrepo mergerepo modifyrepo sqliterepo;do
  ln -s %{_bindir}/$i\_c %{buildroot}%{_sysconfdir}/alternatives/$i
  ln -s %{_sysconfdir}/alternatives/$i %{buildroot}%{_bindir}/$i
  ln -s %{_mandir}/man8/$i\_c.8.gz %{buildroot}%{_sysconfdir}/alternatives/$i\.8.gz
  ln -s %{_sysconfdir}/alternatives/$i\.8.gz %{buildroot}%{_mandir}/man8/$i\.8.gz
done
%endif

%fdupes %{buildroot}%{_prefix}
%fdupes build/doc/html

%if %{with as_createrepo}
%pre
if [ -e %{_sysconfdir}/alternatives/createrepo ]; then
  update-alternatives --remove createrepo %{_bindir}/createrepo_c
fi
%else
%post
update-alternatives --install \
  %{_bindir}/createrepo createrepo %{_bindir}/createrepo_c  20 \
  --slave %{_bindir}/mergerepo mergerepo %{_bindir}/mergerepo_c \
  --slave %{_bindir}/modifyrepo modifyrepo %{_bindir}/modifyrepo_c \
  --slave %{_bindir}/sqliterepo sqliterepo %{_bindir}/sqliterepo_c \
  --slave %{_mandir}/man8/createrepo.8.gz createrepo.8.gz %{_mandir}/man8/createrepo_c.8.gz \
  --slave %{_mandir}/man8/mergerepo.8.gz mergerepo.8.gz %{_mandir}/man8/mergerepo_c.8.gz \
  --slave %{_mandir}/man8/modifyrepo.8.gz modifyrepo.8.gz %{_mandir}/man8/modifyrepo_c.8.gz \
  --slave %{_mandir}/man8/sqliterepo.8.gz sqliterepo.8.gz %{_mandir}/man8/sqliterepo_c.8.gz

%postun
if [ ! -f %{_bindir}/createrepo_c ]; then
  update-alternatives --remove createrepo %{_bindir}/createrepo_c
fi
%endif

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%doc README.md
%license COPYING
%{_mandir}/man8/createrepo_c.8*
%{_mandir}/man8/mergerepo_c.8*
%{_mandir}/man8/modifyrepo_c.8*
%{_mandir}/man8/sqliterepo_c.8*
%{_mandir}/man8/createrepo.8*
%{_mandir}/man8/mergerepo.8*
%{_mandir}/man8/modifyrepo.8*
%{_mandir}/man8/sqliterepo.8*
%{_datadir}/bash-completion/completions/
%{_bindir}/createrepo_c
%{_bindir}/mergerepo_c
%{_bindir}/modifyrepo_c
%{_bindir}/sqliterepo_c
%{_bindir}/createrepo
%{_bindir}/mergerepo
%{_bindir}/modifyrepo
%{_bindir}/sqliterepo
%if ! %{with as_createrepo}
%ghost %_sysconfdir/alternatives/createrepo
%ghost %_sysconfdir/alternatives/mergerepo
%ghost %_sysconfdir/alternatives/modifyrepo
%ghost %_sysconfdir/alternatives/sqliterepo
%ghost %_sysconfdir/alternatives/createrepo.8.gz
%ghost %_sysconfdir/alternatives/mergerepo.8.gz
%ghost %_sysconfdir/alternatives/modifyrepo.8.gz
%ghost %_sysconfdir/alternatives/sqliterepo.8.gz
%endif

%files -n %{libname}
%license COPYING
%{_libdir}/libcreaterepo_c.so.%{major}
%{_libdir}/libcreaterepo_c.so.%{major}.*

%files -n %{devname}
%doc build/doc/html
%license COPYING
%{_libdir}/libcreaterepo_c.so
%{_libdir}/pkgconfig/createrepo_c.pc
%{_includedir}/createrepo_c/

%if %{with python3}
%files -n python3-%{name}
%license COPYING
%{python3_sitearch}/createrepo_c/
%{python3_sitearch}/*egg-info
%endif

%changelog
* Fri Dec  6 2019 Neal Gompa <ngompa13@gmail.com>
- Update to 0.15.4
  + Add reboot_suggested field to UpdateRecord (rh#1772466)
  + Skip directory matching --exclude right away
  + Add restart_suggested to updatecollectionpackage
* Fri Nov 29 2019 Neal Gompa <ngompa13@gmail.com>
- Update to 0.15.3
  + Export all changelog entries in compatibility mode
  + Libmagic to follow symlinks (rh#1776399)
  + Add shortcut to detect *.yaml files as not compressed
- Ensure createrepo_c fully replaces createrepo on Tumbleweed
- Remove old and now unused dependency on deltarpm as drpm is used now
* Mon Nov 25 2019 Neal Gompa <ngompa13@gmail.com>
- Update to 0.15.2
  + Fix file mode for cache (rh#1686812)
  + Honor umask on cache files (rh#1686812)
- Enable DeltaRPM support for openSUSE targets on Leap 15.2+ and TW
* Mon Nov 18 2019 Steve Kowalik <steven.kowalik@suse.com>
- Add BuildRequires on python3, it won't be pulled in side effect of
  requiring python3-nose
* Tue Sep 17 2019 Dirk Mueller <dmueller@suse.com>
- fix build by adding missing tarball and updating filelist
* Tue Sep 17 2019 Frank Schreiner <FSchreiner@suse.com>
- Update to version 0.15.1:
  * Release 0.15.1
  * Fix null pointer crash in cr_dumper_thread() if it fails to get checksum
  * Fix search in string with missing terminating zero (rh#1750673)
  * Depend on DRPM minimum version 0.4.0
  * Release 0.15.0
  * Revise drpm dependency check and bump the minimum version to 0.3.0
  * Release 0.14.4
  * Update documentation and regenerate man pages to sync up
  * Use drpm_make from drpm instead of deltarpm (rh#1687843)
  * Fix some DEBUG build warnings
  * Switch off html timestamps on documentation (rh#1731050)
  * Update documentation for mergerepo_c merge methods (rh#1722803)
  * Update documentation for --retain-old-md and --compatibility
  * Fix --read-pkgs-list to only list actually read packages
  * Release 0.14.3
  * Add missing python metadata to python2/3-createrepo_c (rh#1695677)
  * detect plain tar file as non compressed
* Sat Jun 29 2019 Neal Gompa <ngompa13@gmail.com>
- Update to 0.14.2
  + Fix issue with createrepo_c hanging at the end (rh#1714666)
  + Don't include packages with forbidden control chars in repodata (boo#1110914)
  + Correct pkg count in headers if there were invalid pkgs (rh#1596211)
  + Prevent exiting with 0 if errors occur while finalizing repodata
* Wed May 15 2019 Neal Gompa <ngompa13@gmail.com>
- Update to 0.14.0
  + Fix crash when dumping updateinfo and module is omitted (rh#1707981)
  + Add --pkgorigins mode
* Sat May  4 2019 Neal Gompa <ngompa13@gmail.com>
- Update to 0.13.1
  + Fix tests to work properly when modulemd support is not enabled
- Enable modulemd support on openSUSE Leap 15.1+ and Tumbleweed
* Sat May  4 2019 Neal Gompa <ngompa13@gmail.com>
- Update to 0.13.0
  + Add support for handling modulemd
  + Add support for Koji simple merge mode
  + Add support for zchunked modulemd
  + Fixed --keep-all-metadata to keep all additional metadata
- Disable tests if modulemd support is not enabled to prevent wrong failures
- Drop patches included in this release
  + 0001-Find-correct-nosetests-version-even-when-which-comma.patch
  + 0002-fix-linking-when-Wl-no-undefined-is-set.patch
* Mon Mar 18 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Fri Mar  1 2019 Frank Schreiner <FSchreiner@suse.com>
- Added upstream patches
  * 0001-Find-correct-nosetests-version-even-when-which-comma.patch
  * 0002-fix-linking-when-Wl-no-undefined-is-set.patch
- Drop included patches
  * 0001-zck_end_chunk-returns-number-of-bytes-written-or-1-f.patch
  * 0002-Add-missing-sentinal.patch
  * 0003-Fix-misc-test.patch
- Disable drpm support
- Update to version 0.12.1:
  * Release 0.12.1
  * For make test, xz and zchunk (not just *-devel) are required.
  * Make cmake variable PYTHON_EXECUTABLE global
  * Add zchunk support already to Fedora 29
  * [spec] Fix spec to work for epel 7
  * Add CMake support for python interpreter path
  * Add space after if statement
  * Fix misc test
  * Add missing sentinal
  * Add zchunk support to mergerepo_c for extra files
* Mon Feb  4 2019 Neal Gompa <ngompa13@gmail.com>
- Backport fixes from upstream
  * 0001-zck_end_chunk-returns-number-of-bytes-written-or-1-f.patch
  * 0002-Add-missing-sentinal.patch
  * 0003-Fix-misc-test.patch
* Mon Feb  4 2019 Neal Gompa <ngompa13@gmail.com>
- Update to 0.12.0
  + Add basic support for zchunk metadata
  + Add support for building wheels to upload to PyPI
- Drop Python 2 subpackage
- Enable drpm support
- Enable zchunk for openSUSE Leap 15.1+ and Tumbleweed
- Adjust changes entries to use full author identities
* Wed Aug  1 2018 Neal Gompa <ngompa13@gmail.com>
- Update to 0.11.1
  + Add support for RPMs with large files
  + Identify Requires(missingok) as Recommends correctly
  + Enable legacy tags by default
  + Fix missing packages in mergerepo_c with multiple VR of same name
  + Add mergerepo_c --repo-prefix-search and --repo-prefix-replace
  + Build against Python 3 by default for bindings
- Drop snapshot source service and snapshot tarball
- Use license macro for license file
- Drop trailing whitespace
- Fix comment about drpm support
- [boo#1125044] fix for huge rpm packages
* Thu Apr  5 2018 Adrian Schröter <adrian@suse.de>
- fix spelling of old weakdeps feature switch (bsc#1088328)
* Wed Feb 21 2018 Frank Schreiner <FSchreiner@suse.com>
- [bnc#1075670] changed to provide createrepo as update-alternative
  because createrepo_c will replace createrepo because of switch to
  python3
- also provide createrepo-implementation
* Tue Feb 13 2018 Tomáš Chvátal <tchvatal@suse.com>
- Disable tests on SLE12 due to the python-nose requirements
* Mon Jan 22 2018 Tomáš Chvátal <tchvatal@suse.com>
- Switch to singlespec buidling of python bindings
- Make sure to use cmake macros to have it easier to gork what is
  happending by overriding %%__builddir
- Sort out with spec-cleaner
- Fix embedding of date and time to documentation
* Sun Feb 19 2017 Neal Gompa <ngompa13@gmail.com>
- Enable Python bindings for openSUSE Leap.
* Sun Feb 19 2017 Neal Gompa <ngompa13@gmail.com>
- Enable Python bindings for openSUSE Tumbleweed.
* Wed Feb  8 2017 Neal Gompa <ngompa13@gmail.com>
- Updated upstream sources
- Removed patch 000-Ensure_that_provides-requires_versions_are_factored_into_dep_filtering.diff
  (upstream included equal patch)
- Added missing copyright statements
- Fixed license tag and other misc cleanups
* Mon Oct 31 2016 Frank Schreiner <FSchreiner@suse.com>
- updated upstream sources
- Added patch 000-Ensure_that_provides-requires_versions_are_factored_into_dep_filtering.diff
* Tue Jul  5 2016 Jan Engelhardt <jengelh@inai.de>
- Run fdupes to eliminate duplicate .js files
* Mon Feb  1 2016 Neal Gompa <ngompa13@gmail.com>
- Disable Python 3 bindings for SLE
* Mon Feb  1 2016 Neal Gompa <ngompa13@gmail.com>
- Update to 0.10.0, add Python 3 bindings
* Thu Oct 29 2015 Neal Gompa <ngompa13@gmail.com>
- Initial package based on Mageia package
